#
# spec file for package menulibre
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git

Name:           menulibre
Version:        2.2.1
Release:        bp153.1.16
Summary:        Desktop menu editor
License:        GPL-3.0-only
Group:          System/GUI/Other
URL:            https://bluesabre.org/projects/menulibre/
Source:         https://launchpad.net/menulibre/2.2/%{version}/+download/%{name}-%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gnome-menus
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  python3
BuildRequires:  python3-base
BuildRequires:  python3-distutils-extra
BuildRequires:  python3-gobject
BuildRequires:  python3-psutil
BuildRequires:  update-desktop-files
BuildRequires:  xdg-utils
BuildRequires:  typelib(Gtk) = 3.0
Requires:       gnome-menus
Requires:       hicolor-icon-theme
Requires:       python3
Requires:       python3-gobject
Requires:       python3-psutil
Requires:       xdg-utils
Recommends:     %{name}-lang
BuildArch:      noarch

%description
A desktop menu editor. Budgie, Cinnamon, GNOME, KDE (Plasma), LXDE, LXQt, MATE,
Pantheon, Unity, and Xfce are supported.

%lang_package

%prep
%autosetup

%build

%install
%{__python3} setup.py install --root=%{buildroot}

# Remove hashbang line from non-executable library files
for lib in %{buildroot}%{python3_sitelib}/menulibre{,_lib}/*.py; do
    sed '1{\@^#!/usr/bin/python3@d}' $lib > $lib.new &&
    touch -r $lib $lib.new &&
    mv $lib.new $lib
done

# Fix name issue in menulibre.desktop with Budgie and Pantheon
desktop-file-edit %{buildroot}%{_datadir}/applications/%{name}.desktop --remove-only-show-in="Pantheon" \
  --remove-only-show-in="Budgie"
desktop-file-edit %{buildroot}%{_datadir}/applications/%{name}.desktop --add-only-show-in="X-Pantheon" \
  --add-only-show-in="X-Budgie"

# Fix python-bytecode-inconsistent-mtime.
pushd %{buildroot}%{python3_sitelib}/%{name}_lib
%py3_compile .
popd

# Fix duplicate doc folder
rm -rf %{buildroot}%{_datadir}/doc

# Fix duplicate icon
%fdupes %{buildroot}%{_datadir}/icons/hicolor/

desktop-file-validate %{buildroot}/%{_datadir}/applications/menulibre.desktop

%find_lang %{name}

%files -f %{name}.lang

%files
%license COPYING
%doc AUTHORS NEWS README
%{_bindir}/%{name}*
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor/
%dir %{_datadir}/icons/hicolor/64x64/apps/
%dir %{_datadir}/icons/hicolor/48x48/apps/
%dir %{_datadir}/icons/hicolor/32x32/apps/
%dir %{_datadir}/icons/hicolor/24x24/apps/
%dir %{_datadir}/icons/hicolor/16x16/apps/
%dir %{_datadir}/icons/hicolor/scalable/apps/
%{_datadir}/icons/hicolor/64x64/apps/%{name}.svg
%{_datadir}/icons/hicolor/48x48/apps/%{name}.svg
%{_datadir}/icons/hicolor/32x32/apps/%{name}.svg
%{_datadir}/icons/hicolor/24x24/apps/%{name}.svg
%{_datadir}/icons/hicolor/16x16/apps/%{name}.svg
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man?/%{name}*.?%{ext_man}
%{python3_sitelib}/%{name}-%{version}-py%{py3_ver}.egg-info
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}_lib/
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/ui/
%{_datadir}/%{name}/ui/*.ui

%changelog
* Fri May 31 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Polished spec file:
  - Remove hashbang line from non-executable library files
  - Replaced python3 with %%{__python3} macro
  - Added check with desktop-file-validate
* Fri May 31 2019 Vinzenz Vietzke <vinz@vinzv.de>
- Update version to 2.2.1
  * Automatically generate changelog when built from git or released
  * Bug Fixes
  - Correctly display markup in the application name (lp#1813427)
  - Fix UnicodeDecodeError with non-English locales (lp#1825213)
  - Drop invalid error for non-existent Exec key (lp#1788814)
  - Decode stderr as UTF-8 (lp#1789635)
  * Translation Updates
* Fri Oct 12 2018 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description.
* Fri Oct 12 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Added fix for duplicate icons warnings
- Added BuildRequires: hicolor-icon-theme
- Added Requres: xdg-utils, hicolor-icon-theme
- Run spec-cleaner
* Fri Oct 12 2018 Maurizio Galli <maurizio.galli@gmail.com>
- added %%{__python3} macro in %%install section
* Fri Oct 12 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Added fix duplicate doc folder in spec file
- Cleaned Change Log
- Modified %%install to include Python binary path
- Fixed several BuildRequires and Requires dependencies
- typelib(gtk) = 3.0 needed as RB to prevent some Python module errors during build
- Edited %%build arguments
- Cleaned %%file section and added folders and files
- Run spec-cleaner
* Wed Oct 10 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Changed license in spec file to GPL-3.0-only
- Removed # FIXME comments in spec file
* Mon Oct  8 2018 Maurizio Galli <maurizio.galli@gmail.com>
- fixed Source address
* Sun Oct  7 2018 Maurizio Galli <maurizio.galli@gmail.com>
- run spec-cleaner and cleaned up spec file
- removed duplicate dependency
* Mon Oct  1 2018 Maurizio Galli <maurizio.galli@gmail.com>
- menulibre-2.2.0
- New Package
